@@ -70,6 +70,7 @@ TypeType = Literal["PullRequest", "RepositoryAnalysis"]
 VendorNameType = Literal["GitHub", "GitLab", "NativeS3"]
 ServiceName = Literal[
     "accessanalyzer",
+    "account",
     "acm",
     "acm-pca",
     "alexaforbusiness",
@@ -102,6 +103,7 @@ ServiceName = Literal[
     "chime-sdk-identity",
     "chime-sdk-messaging",
     "cloud9",
+    "cloudcontrol",
     "clouddirectory",
     "cloudformation",
     "cloudfront",
